@@ -1,14 +1,14 @@
 /*
  * Sample program to use PC/SC API.
  *
- * MUSCLE SmartCard Development ( http://www.linuxnet.com )
+ * MUSCLE SmartCard Development ( http://pcsclite.alioth.debian.org/pcsclite.html )
  *
- * Copyright (C) 2003-2009
+ * Copyright (C) 2003-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,10 +17,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: pcsc_demo.c 4468 2009-10-08 13:16:38Z rousseau $
+ * $Id: pcsc_demo.c 6851 2014-02-14 15:43:32Z rousseau $
  */
 
 #include <stdio.h>
@@ -63,7 +62,7 @@ int main(int argc, char *argv[])
 	char pbReader[MAX_READERNAME] = "";
 	int reader_nb;
 	unsigned int i;
-    SCARD_IO_REQUEST *pioSendPci;
+	const SCARD_IO_REQUEST *pioSendPci;
 	SCARD_IO_REQUEST pioRecvPci;
 	BYTE pbRecvBuffer[10];
 	BYTE pbSendBuffer[] = { 0x00, 0xA4, 0x00, 0x00, 0x02, 0x3F, 0x00 };
@@ -232,7 +231,7 @@ int main(int argc, char *argv[])
 	/* get card status change */
 	{
 		/* check only one reader */
-		SCARD_READERSTATE_A rgReaderStates[1];
+		SCARD_READERSTATE rgReaderStates[1];
 
 		rgReaderStates[0].szReader = pbReader;
 		rgReaderStates[0].dwCurrentState = SCARD_STATE_UNAWARE;
