@@ -18,7 +18,7 @@ int pcsc_assert_wire_constants(void)
 
         LASSERTF(PROTOCOL_VERSION_MAJOR == 4," found %lld\n",
                  (long long)PROTOCOL_VERSION_MAJOR);
-        LASSERTF(PROTOCOL_VERSION_MINOR == 0," found %lld\n",
+        LASSERTF(PROTOCOL_VERSION_MINOR == 2," found %lld\n",
                  (long long)PROTOCOL_VERSION_MINOR);
 
         LASSERTF(MAX_READERNAME == 100," found %lld\n",
@@ -240,37 +240,13 @@ int pcsc_assert_wire_constants(void)
                  (long long)(int)sizeof(((struct cancel_struct *)0)->rv));
 
         /* Checks for struct status_struct */
-        LASSERTF((int)sizeof(struct status_struct) == 160, " found %lld\n",
+        LASSERTF((int)sizeof(struct status_struct) == 8, " found %lld\n",
                  (long long)(int)sizeof(struct status_struct));
         LASSERTF((int)offsetof(struct status_struct, hCard) == 0, " found %lld\n",
                  (long long)(int)offsetof(struct status_struct, hCard));
         LASSERTF((int)sizeof(((struct status_struct *)0)->hCard) == 4, " found %lld\n",
                  (long long)(int)sizeof(((struct status_struct *)0)->hCard));
-        LASSERTF((int)offsetof(struct status_struct, mszReaderNames) == 4, " found %lld\n",
-                 (long long)(int)offsetof(struct status_struct, mszReaderNames));
-        LASSERTF((int)sizeof(((struct status_struct *)0)->mszReaderNames) == 100, " found %lld\n",
-                 (long long)(int)sizeof(((struct status_struct *)0)->mszReaderNames));
-        LASSERTF((int)offsetof(struct status_struct, pcchReaderLen) == 104, " found %lld\n",
-                 (long long)(int)offsetof(struct status_struct, pcchReaderLen));
-        LASSERTF((int)sizeof(((struct status_struct *)0)->pcchReaderLen) == 4, " found %lld\n",
-                 (long long)(int)sizeof(((struct status_struct *)0)->pcchReaderLen));
-        LASSERTF((int)offsetof(struct status_struct, dwState) == 108, " found %lld\n",
-                 (long long)(int)offsetof(struct status_struct, dwState));
-        LASSERTF((int)sizeof(((struct status_struct *)0)->dwState) == 4, " found %lld\n",
-                 (long long)(int)sizeof(((struct status_struct *)0)->dwState));
-        LASSERTF((int)offsetof(struct status_struct, dwProtocol) == 112, " found %lld\n",
-                 (long long)(int)offsetof(struct status_struct, dwProtocol));
-        LASSERTF((int)sizeof(((struct status_struct *)0)->dwProtocol) == 4, " found %lld\n",
-                 (long long)(int)sizeof(((struct status_struct *)0)->dwProtocol));
-        LASSERTF((int)offsetof(struct status_struct, pbAtr) == 116, " found %lld\n",
-                 (long long)(int)offsetof(struct status_struct, pbAtr));
-        LASSERTF((int)sizeof(((struct status_struct *)0)->pbAtr) == 33, " found %lld\n",
-                 (long long)(int)sizeof(((struct status_struct *)0)->pbAtr));
-        LASSERTF((int)offsetof(struct status_struct, pcbAtrLen) == 152, " found %lld\n",
-                 (long long)(int)offsetof(struct status_struct, pcbAtrLen));
-        LASSERTF((int)sizeof(((struct status_struct *)0)->pcbAtrLen) == 4, " found %lld\n",
-                 (long long)(int)sizeof(((struct status_struct *)0)->pcbAtrLen));
-        LASSERTF((int)offsetof(struct status_struct, rv) == 156, " found %lld\n",
+        LASSERTF((int)offsetof(struct status_struct, rv) == 4, " found %lld\n",
                  (long long)(int)offsetof(struct status_struct, rv));
         LASSERTF((int)sizeof(((struct status_struct *)0)->rv) == 4, " found %lld\n",
                  (long long)(int)sizeof(((struct status_struct *)0)->rv));
@@ -362,11 +338,7 @@ int pcsc_assert_wire_constants(void)
         /* Checks for struct pubReaderStatesList */
         LASSERTF((int)sizeof(struct pubReaderStatesList) == 156, " found %lld\n",
                  (long long)(int)sizeof(struct pubReaderStatesList));
-        LASSERTF((int)offsetof(struct pubReaderStatesList, readerID) == 0, " found %lld\n",
-                 (long long)(int)offsetof(struct pubReaderStatesList, readerID));
-        LASSERTF((int)sizeof(((struct pubReaderStatesList *)0)->readerID) == 4, " found %lld\n",
-                 (long long)(int)sizeof(((struct pubReaderStatesList *)0)->readerID));
-        LASSERTF((int)offsetof(struct pubReaderStatesList, readerName) == 4, " found %lld\n",
+        LASSERTF((int)offsetof(struct pubReaderStatesList, readerName) == 0, " found %lld\n",
                  (long long)(int)offsetof(struct pubReaderStatesList, readerName));
         LASSERTF((int)sizeof(((struct pubReaderStatesList *)0)->readerName) == 100, " found %lld\n",
                  (long long)(int)sizeof(((struct pubReaderStatesList *)0)->readerName));
