@@ -1,10 +1,33 @@
 /*
- * MUSCLE SmartCard Development ( http://www.linuxnet.com )
+ * MUSCLE SmartCard Development ( http://pcsclite.alioth.debian.org/pcsclite.html )
  *
  * Copyright (C) 2006-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: utils.c 6696 2013-07-30 12:55:15Z rousseau $
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+1. Redistributions of source code must retain the above copyright
+   notice, this list of conditions and the following disclaimer.
+2. Redistributions in binary form must reproduce the above copyright
+   notice, this list of conditions and the following disclaimer in the
+   documentation and/or other materials provided with the distribution.
+3. The name of the author may not be used to endorse or promote products
+   derived from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * $Id: utils.c 7004 2014-10-02 09:26:36Z rousseau $
  */
 
 /**
@@ -129,6 +152,7 @@ int ThreadCreate(pthread_t * pthThread, int attributes,
 	PCSCLITE_THREAD_FUNCTION(pvFunction), LPVOID pvArg)
 {
 	pthread_attr_t attr;
+	size_t stack_size;
 	int ret;
 
 	ret = pthread_attr_init(&attr);
@@ -138,15 +162,24 @@ int ThreadCreate(pthread_t * pthThread, int attributes,
 	ret = pthread_attr_setdetachstate(&attr,
 		attributes & THREAD_ATTR_DETACHED ? PTHREAD_CREATE_DETACHED : PTHREAD_CREATE_JOINABLE);
 	if (ret)
+		goto error;
+
+	/* stack size of 0x40000 (256 KB) bytes minimum for musl C lib */
+	ret = pthread_attr_getstacksize(&attr, &stack_size);
+	if (ret)
+		goto error;
+
+	if (stack_size < 0x40000)
 	{
-		(void)pthread_attr_destroy(&attr);
-		return ret;
+		stack_size = 0x40000;
+		ret = pthread_attr_setstacksize(&attr, stack_size);
+		if (ret)
+			goto error;
 	}
 
 	ret = pthread_create(pthThread, &attr, pvFunction, pvArg);
-	if (ret)
-		return ret;
 
-	ret = pthread_attr_destroy(&attr);
+error:
+	pthread_attr_destroy(&attr);
 	return ret;
 }
